@@ -83,6 +83,12 @@ typedef struct
   /* the device the operation is working on */
   ThunarDevice         *device;
 
+  /* for user interaction during the [un]mount operation */
+  GMountOperation *mount_operation;
+
+  /* the handler ID for the show-umount-progress signal */
+  gulong unmount_progress_signal_id;
+
   /* finish function for the async callback */
   AsyncCallbackFinish   callback_finish;
 
@@ -222,8 +228,22 @@ thunar_device_set_property (GObject      *object,
 
 
 
+static void
+show_unmount_progress_cb (GMountOperation *mount_operation,
+                          const gchar     *message_to_show,
+                          gint64           time_left,
+                          gint64           bytes_left,
+                          ThunarDevice    *device)
+{
+  if (message_to_show != NULL)
+    thunar_notify_progress (device, message_to_show);
+}
+
+
+
 static ThunarDeviceOperation *
 thunar_device_operation_new (ThunarDevice         *device,
+                             GMountOperation      *mount_operation,
                              ThunarDeviceCallback  callback,
                              gpointer              user_data,
                              gpointer              callback_finish)
@@ -232,6 +252,9 @@ thunar_device_operation_new (ThunarDevice         *device,
 
   op = g_slice_new0 (ThunarDeviceOperation);
   op->device = g_object_ref (device);
+  op->mount_operation = g_object_ref (mount_operation);
+  op->unmount_progress_signal_id = g_signal_connect (mount_operation,
+      "show-unmount-progress", G_CALLBACK (show_unmount_progress_cb), device);
   op->callback = callback;
   op->callback_finish = callback_finish;
   op->user_data = user_data;
@@ -276,6 +299,8 @@ thunar_device_operation_finish (GObject      *object,
 
   /* cleanup */
   g_clear_error (&error);
+  g_signal_handler_disconnect (op->mount_operation, op->unmount_progress_signal_id);
+  g_object_unref (G_OBJECT (op->mount_operation));
   g_object_unref (G_OBJECT (op->device));
   g_slice_free (ThunarDeviceOperation, op);
 }
@@ -393,6 +418,25 @@ thunar_device_get_identifier (const ThunarDevice *device)
 
 
 
+gchar *
+thunar_device_get_identifier_unix (const ThunarDevice *device)
+{
+  gchar *ident = NULL;
+
+  _thunar_return_val_if_fail (THUNAR_IS_DEVICE (device), NULL);
+
+  if (G_IS_VOLUME (device->device))
+    ident = g_volume_get_identifier (device->device, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+  else if (G_IS_MOUNT (device->device))
+    return NULL;
+  else
+    _thunar_assert_not_reached ();
+
+  return ident;
+}
+
+
+
 gboolean
 thunar_device_get_hidden (const ThunarDevice *device)
 {
@@ -443,6 +487,48 @@ thunar_device_can_eject (const ThunarDevice *device)
 
 
 
+/**
+ * thunar_device_get_eject_label:
+ * @device: a #ThunarDevice
+ *
+ * Obtains the recommended name for the eject action,
+ * specific to GIO's drive type.
+ *
+ * Return value: The recommended name of the eject action. The returned string must not be freed.
+ **/
+const gchar *
+thunar_device_get_eject_label (const ThunarDevice *device)
+{
+    GDrive              *drive = NULL;
+    GDriveStartStopType  start_stop_type = G_DRIVE_START_STOP_TYPE_UNKNOWN;
+
+    if (G_IS_VOLUME (device->device))
+      drive = g_volume_get_drive (device->device);
+
+    if (drive != NULL)
+      {
+        start_stop_type = g_drive_get_start_stop_type (drive);
+        g_object_unref (drive);
+      }
+
+    switch (start_stop_type)
+      {
+      case G_DRIVE_START_STOP_TYPE_SHUTDOWN:
+        return _("_Safely Remove");
+      case G_DRIVE_START_STOP_TYPE_NETWORK:
+        return _("_Disconnect");
+      case G_DRIVE_START_STOP_TYPE_MULTIDISK:
+        return _("_Stop the Multi-Disk Drive");
+      case G_DRIVE_START_STOP_TYPE_PASSWORD:
+        return _("_Lock");
+      case G_DRIVE_START_STOP_TYPE_UNKNOWN:
+      default:
+        return _("_Eject");
+      }
+}
+
+
+
 /**
  * thunar_device_can_mount:
  *
@@ -610,7 +696,7 @@ thunar_device_mount (ThunarDevice         *device,
 
   if (G_IS_VOLUME (device->device))
     {
-      op = thunar_device_operation_new (device, callback, user_data,
+      op = thunar_device_operation_new (device, mount_operation, callback, user_data,
                                         g_volume_mount_finish);
       g_volume_mount (G_VOLUME (device->device),
                       G_MOUNT_MOUNT_NONE,
@@ -661,7 +747,7 @@ thunar_device_unmount (ThunarDevice         *device,
 
           /* try unmounting the mount */
           thunar_device_emit_pre_unmount (device, FALSE);
-          op = thunar_device_operation_new (device, callback, user_data,
+          op = thunar_device_operation_new (device, mount_operation, callback, user_data,
                                             g_mount_unmount_with_operation_finish);
           g_mount_unmount_with_operation (mount,
                                           G_MOUNT_UNMOUNT_NONE,
@@ -713,7 +799,7 @@ thunar_device_eject (ThunarDevice         *device,
 
               /* try to stop the drive */
               thunar_device_emit_pre_unmount (device, TRUE);
-              op = thunar_device_operation_new (device, callback, user_data,
+              op = thunar_device_operation_new (device, mount_operation, callback, user_data,
                                                 g_drive_stop_finish);
               g_drive_stop (drive,
                             G_MOUNT_UNMOUNT_NONE,
@@ -734,7 +820,7 @@ thunar_device_eject (ThunarDevice         *device,
 
               /* try to stop the drive */
               thunar_device_emit_pre_unmount (device, TRUE);
-              op = thunar_device_operation_new (device, callback, user_data,
+              op = thunar_device_operation_new (device, mount_operation, callback, user_data,
                                                 g_drive_eject_with_operation_finish);
               g_drive_eject_with_operation (drive,
                                             G_MOUNT_UNMOUNT_NONE,
@@ -759,7 +845,7 @@ thunar_device_eject (ThunarDevice         *device,
 
           /* try ejecting the volume */
           thunar_device_emit_pre_unmount (device, TRUE);
-          op = thunar_device_operation_new (device, callback, user_data,
+          op = thunar_device_operation_new (device, mount_operation, callback, user_data,
                                             g_volume_eject_with_operation_finish);
           g_volume_eject_with_operation (volume,
                                          G_MOUNT_UNMOUNT_NONE,
@@ -794,7 +880,7 @@ thunar_device_eject (ThunarDevice         *device,
 
           /* try ejecting the mount */
           thunar_device_emit_pre_unmount (device, FALSE);
-          op = thunar_device_operation_new (device, callback, user_data,
+          op = thunar_device_operation_new (device, mount_operation, callback, user_data,
                                             g_mount_eject_with_operation_finish);
           g_mount_eject_with_operation (mount,
                                         G_MOUNT_UNMOUNT_NONE,
@@ -810,7 +896,7 @@ thunar_device_eject (ThunarDevice         *device,
 
           /* try unmounting the mount */
           thunar_device_emit_pre_unmount (device, FALSE);
-          op = thunar_device_operation_new (device, callback, user_data,
+          op = thunar_device_operation_new (device, mount_operation, callback, user_data,
                                             g_mount_unmount_with_operation_finish);
           g_mount_unmount_with_operation (mount,
                                           G_MOUNT_UNMOUNT_NONE,
