@@ -60,6 +60,7 @@ typedef enum
   THUNAR_FILE_DATE_CREATED,
   THUNAR_FILE_DATE_MODIFIED,
   THUNAR_FILE_DATE_DELETED,
+  THUNAR_FILE_RECENCY,
 } ThunarFileDateType;
 
 /**
@@ -124,6 +125,7 @@ ThunarFile       *thunar_file_get                        (GFile
                                                           GError                **error);
 ThunarFile       *thunar_file_get_with_info              (GFile                  *file,
                                                           GFileInfo              *info,
+                                                          GFileInfo              *recent_info,
                                                           gboolean                not_mounted);
 ThunarFile       *thunar_file_get_for_uri                (const gchar            *uri,
                                                           GError                **error);
@@ -213,6 +215,8 @@ gboolean          thunar_file_is_home                    (const ThunarFile
 gboolean          thunar_file_is_regular                 (const ThunarFile       *file) G_GNUC_PURE;
 gboolean          thunar_file_is_trash                   (const ThunarFile       *file);
 gboolean          thunar_file_is_trashed                 (const ThunarFile       *file);
+gboolean          thunar_file_is_recent                  (const ThunarFile       *file);
+gboolean          thunar_file_is_in_recent               (const ThunarFile       *file);
 gboolean          thunar_file_is_desktop_file            (const ThunarFile       *file,
                                                           gboolean               *is_secure);
 const gchar      *thunar_file_get_display_name           (const ThunarFile       *file) G_GNUC_CONST;
@@ -220,6 +224,9 @@ const gchar      *thunar_file_get_display_name           (const ThunarFile
 gchar            *thunar_file_get_deletion_date          (const ThunarFile       *file,
                                                           ThunarDateStyle         date_style,
                                                           const gchar            *date_custom_style) G_GNUC_MALLOC G_GNUC_WARN_UNUSED_RESULT;
+gchar            *thunar_file_get_recency                (const ThunarFile       *file,
+                                                          ThunarDateStyle         date_style,
+                                                          const gchar            *date_custom_style) G_GNUC_MALLOC G_GNUC_WARN_UNUSED_RESULT;
 const gchar      *thunar_file_get_original_path          (const ThunarFile       *file);
 guint32           thunar_file_get_item_count             (const ThunarFile       *file);
 
@@ -277,7 +284,8 @@ const gchar*      thunar_file_get_metadata_setting       (ThunarFile
                                                           const gchar            *setting_name);
 void              thunar_file_set_metadata_setting       (ThunarFile             *file,
                                                           const gchar            *setting_name,
-                                                          const gchar            *setting_value);
+                                                          const gchar            *setting_value,
+                                                          gboolean                async);
 void              thunar_file_clear_directory_specific_settings (ThunarFile      *file);
 gboolean          thunar_file_has_directory_specific_settings   (ThunarFile      *file);
 
