@@ -276,7 +276,7 @@ thunar_location_button_finalize (GObject *object)
   ThunarLocationButton *location_button = THUNAR_LOCATION_BUTTON (object);
 
   /* release the drop path list (just in case the drag-leave wasn't fired before) */
-  thunar_g_file_list_free (location_button->drop_file_list);
+  thunar_g_list_free_full (location_button->drop_file_list);
 
   /* be sure to cancel any pending enter timeout */
   if (G_UNLIKELY (location_button->enter_timeout_id != 0))
@@ -721,7 +721,7 @@ thunar_location_button_drag_leave (GtkWidget            *button,
   /* reset the "drop data ready" status and free the path list */
   if (G_LIKELY (location_button->drop_data_ready))
     {
-      thunar_g_file_list_free (location_button->drop_file_list);
+      thunar_g_list_free_full (location_button->drop_file_list);
       location_button->drop_data_ready = FALSE;
       location_button->drop_file_list = NULL;
     }
