@@ -178,6 +178,10 @@ void           _thunar_standard_view_open_on_middle_click (ThunarStandardView
                                                            GtkTreePath              *tree_path,
                                                            guint                     event_state);
 
+void           thunar_standard_view_set_searching         (ThunarStandardView       *standard_view,
+                                                           gchar                    *search_query);
+gchar         *thunar_standard_view_get_search_query      (ThunarStandardView       *standard_view);
+
 G_END_DECLS;
 
 #endif /* !__THUNAR_STANDARD_VIEW_H__ */
