@@ -320,12 +320,15 @@ thunar_tree_model_init (ThunarTreeModel *model)
 
   /* append the computer icon if browsing the computer is supported */
   if (thunar_g_vfs_is_uri_scheme_supported ("computer"))
-    system_paths = g_list_append (system_paths, g_file_new_for_uri ("computer://"));
+    system_paths = g_list_append (system_paths, thunar_g_file_new_for_computer());
 
   /* add the home folder to the system paths */
   home = thunar_g_file_new_for_home ();
   system_paths = g_list_append (system_paths, g_object_ref (home));
 
+  if (thunar_g_vfs_is_uri_scheme_supported ("recent"))
+    system_paths = g_list_append (system_paths, thunar_g_file_new_for_recent());
+
   /* append the trash icon if the trash is supported */
   if (thunar_g_vfs_is_uri_scheme_supported ("trash"))
     system_paths = g_list_append (system_paths, thunar_g_file_new_for_trash ());
@@ -335,7 +338,7 @@ thunar_tree_model_init (ThunarTreeModel *model)
 
   /* append the network icon if browsing the network is supported */
   if (thunar_g_vfs_is_uri_scheme_supported ("network"))
-    system_paths = g_list_append (system_paths, g_file_new_for_uri ("network://"));
+    system_paths = g_list_append (system_paths, thunar_g_file_new_for_network());
 
   /* append the system defined nodes ('Computer', 'Home', 'Trash', 'File System', 'Network') */
   for (lp = system_paths; lp != NULL; lp = lp->next)
